summaryrefslogtreecommitdiffstats
path: root/testserver.pl
diff options
context:
space:
mode:
authortimeless%mozdev.org <>2007-07-25 01:22:01 +0200
committertimeless%mozdev.org <>2007-07-25 01:22:01 +0200
commite6acfe2ddff74715b097684bebf2d4ee50ff3f11 (patch)
tree06952afe2e977c292c3ca48a4a2ca426a69e4d4b /testserver.pl
parent000f365fbbbbc77352937a2dd85c870be9986ff7 (diff)
downloadbugzilla-e6acfe2ddff74715b097684bebf2d4ee50ff3f11.tar.gz
bugzilla-e6acfe2ddff74715b097684bebf2d4ee50ff3f11.tar.xz
Bug 345970 Avoid using the string 'the web'
patch by jhulten@tragicallyleet.com r=timeless I've updated it to trunk r=lpsolit a=lpsolit
Diffstat (limited to 'testserver.pl')
-rwxr-xr-xtestserver.pl12
1 files changed, 6 insertions, 6 deletions
diff --git a/testserver.pl b/testserver.pl
index 108a19ac2..6169a77e0 100755
--- a/testserver.pl
+++ b/testserver.pl
@@ -45,7 +45,7 @@ if ((@ARGV != 1) || ($ARGV[0] !~ /^https?:/))
}
# Try to determine the GID used by the webserver.
my @pscmds = ('ps -eo comm,gid', 'ps -acxo command,gid', 'ps -acxo command,rgid');
my $sgid = 0;
if ($^O !~ /MSWin32/i) {
@@ -82,7 +82,7 @@ Bugzilla documentation.\n";
print
"TEST-WARNING Webserver is running under group id not matching \$webservergroup.
This if the tests below fail, this is probably the problem.
-Please refer to the webserver configuration section of the Bugzilla guide.
+Please refer to the web server configuration section of the Bugzilla guide.
If you are using virtual hosts or suexec, this warning may not apply.\n";
}
} elsif ($^O !~ /MSWin32/i) {
@@ -100,8 +100,8 @@ if (fetch($url)) {
} else {
print
"TEST-FAILED Fetch of skins/standard/index/front.png failed
-Your webserver could not fetch $url.
-Check your webserver configuration and try again.\n";
+Your web server could not fetch $url.
+Check your web server configuration and try again.\n";
exit(1);
}
@@ -118,7 +118,7 @@ Check the AddHandler statement in your httpd.conf file.\n";
print "TEST-FAILED Webserver is not executing CGI files.\n";
}
# Make sure that webserver is honoring .htaccess files
my $localconfig = bz_locations()->{'localconfig'};
$localconfig =~ s~^\./~~;
$url = $ARGV[0] . "/$localconfig";
@@ -127,7 +127,7 @@ if ($response) {
print
"TEST-FAILED Webserver is permitting fetch of $url.
This is a serious security problem.
-Check your webserver configuration.\n";
+Check your web server configuration.\n";
exit(1);
} else {
print "TEST-OK Webserver is preventing fetch of $url.\n";
@@ -45,7 +45,7 @@ if ((@ARGV != 1) || ($ARGV[0] !~ /^https?:/))
}
-# Try to determine the GID used by the webserver.
+# Try to determine the GID used by the web server.
my @pscmds = ('ps -eo comm,gid', 'ps -acxo command,gid', 'ps -acxo command,rgid');
my $sgid = 0;
@@ -118,7 +118,7 @@ Check the AddHandler statement in your httpd.conf file.\n";
print "TEST-FAILED Webserver is not executing CGI files.\n";
}
-# Make sure that webserver is honoring .htaccess files
+# Make sure that the web server is honoring .htaccess files
my $localconfig = bz_locations()->{'localconfig'};
$localconfig =~ s~^\./~~;